Crate scyllax_macros

Crate scyllax_macros 

Macros supporting scyllax.

See the scyllax docs for more information.

Macros

create_query_collection

Attribute Macros

entity
Shorthand for applying derive macros on an entity. Essentially:
int_enum
Sets up a scylla-and-protobuf compatible enum.
json_data
Shorthand for applying derive macros on a JSON body. Essentially:
upsert_query
Apply this attribute to a entity struct to generate an upsert query.
write_query
Apply this attribute to a struct to generate a write query.

Derive Macros

Entity
Implements scyllax::EntityExt for the struct.
IntEnum
Implements
JsonData
Implements
ReadQuery
Apply this attribute to a struct to generate a select query.