Macros supporting scyllax.
See the scyllax docs for more information.
Macros
Attribute Macros
- entity
- Shorthand for applying derive macros on an entity. Essentially:
- int_
enum - Sets up a scylla-and-protobuf compatible enum.
- json_
data - Shorthand for applying derive macros on a JSON body. Essentially:
- upsert_
query - Apply this attribute to a entity struct to generate an upsert query.
- write_
query - Apply this attribute to a struct to generate a write query.
Derive Macros
- Entity
- Implements
scyllax::EntityExtfor the struct. - IntEnum
- Implements
- Json
Data - Implements
- Read
Query - Apply this attribute to a struct to generate a select query.